cvxpy: A domain-specific language for modeling convex optimization problems in Python.
======================================================================================

Description
-----------

A domain-specific language for modeling convex optimization problems in Python.

License
-------

Apache License, Version 2.0

Upstream Contact
----------------

https://pypi.org/project/cvxpy/

